@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.5002';
+our $VERSION = '0.5003';
 
 use Moo;
 use strictures 2;
@@ -703,7 +703,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.5002
+version 0.5003
 
 =head1 SYNOPSIS
 
@@ -736,9 +736,6 @@ version 0.5002
   $d->note($d->sixteenth, $d->crash1);
   $d->accent_note(127, $d->sixteenth, $d->crash2);
 
-  my $patterns = [ your_function(5, 16), your_function(7, 16) ];
-  $d->pattern( instrument => $d->kick, patterns => $patterns );
-
   # Alternate kick and snare
   $d->note($d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare)
     for 1 .. $d->beats * $d->bars;
@@ -752,6 +749,12 @@ version 0.5002
 
   $d->add_fill('...'); # see doc...
 
+  my $patterns = [
+    your_function(5, 16), # e.g. a euclidean function
+    your_function(7, 16), # ...
+  ];
+  $d->pattern( instrument => $d->kick, patterns => $patterns ); # see doc...
+
   print 'Count: ', $d->counter, "\n";
 
   # As a convenience, and sometimes necessity:
@@ -1099,6 +1102,10 @@ tokens, like the digits 0-9.  Each coderef duration should add up to
 the given B<duration> option.  The single argument to the coderefs is
 the object itself and may be used as: C<my $self = shift;> in yours.
 
+These patterns can be generated with any custom function, as in the
+L</SYNOPSIS>. For instance, you could use the L<Creating::Rhythms>
+module to generate Euclidean patterns.
+
 Defaults:
 
   instrument: snare
